==> python-confluent-kafka_0.11.5.orig.tar.gz: confluent-kafka-0.11.5/setup.py <==
#!/usr/bin/env python

import os
from setuptools import setup, find_packages
from distutils.core import Extension
import sys

INSTALL_REQUIRES = list()

if sys.version_info[0] < 3:
    avro = 'avro'
    INSTALL_REQUIRES.extend(['futures', 'enum34'])
else:
    avro = 'avro-python3'

module = Extension('confluent_kafka.cimpl',
                   libraries=['rdkafka'],
                   sources=['confluent_kafka/src/confluent_kafka.c',
                            'confluent_kafka/src/Producer.c',
                            'confluent_kafka/src/Consumer.c',
                            'confluent_kafka/src/Metadata.c',
                            'confluent_kafka/src/AdminTypes.c',
                            'confluent_kafka/src/Admin.c'])


def get_install_requirements(path):
    content = open(os.path.join(os.path.dirname(__file__), path)).read()
    return [
        req
        for req in content.split("\n")
        if req != '' and not req.startswith('#')
    ]


setup(name='confluent-kafka',
      version='0.11.5',
      description='Confluent\'s Apache Kafka client for Python',
      author='Confluent Inc',
      author_email='support@confluent.io',
      url='https://github.com/confluentinc/confluent-kafka-python',
      ext_modules=[module],
      packages=find_packages(exclude=("tests", "tests.*")),
      data_files=[('', ['LICENSE.txt'])],
      install_requires=INSTALL_REQUIRES,
      extras_require={
          'avro': ['fastavro', 'requests', avro],
          'dev': get_install_requirements("test-requirements.txt")
      })

==> python-confluent-kafka_0.11.6.orig.tar.gz: confluent-kafka-0.11.6/setup.py <==
#!/usr/bin/env python

import os
from setuptools import setup, find_packages
from distutils.core import Extension
import sys
import platform

INSTALL_REQUIRES = list()

if sys.version_info[0] < 3:
    avro = 'avro'
    INSTALL_REQUIRES.extend(['futures', 'enum34'])
else:
    avro = 'avro-python3'

# On Un*x the library is linked as -lrdkafka,
# while on windows we need the full librdkafka name.
if platform.system() == 'Windows':
    librdkafka_libname = 'librdkafka'
else:
    librdkafka_libname = 'rdkafka'

module = Extension('confluent_kafka.cimpl',
                   libraries=[librdkafka_libname],
                   sources=['confluent_kafka/src/confluent_kafka.c',
                            'confluent_kafka/src/Producer.c',
                            'confluent_kafka/src/Consumer.c',
                            'confluent_kafka/src/Metadata.c',
                            'confluent_kafka/src/AdminTypes.c',
                            'confluent_kafka/src/Admin.c'])


def get_install_requirements(path):
    content = open(os.path.join(os.path.dirname(__file__), path)).read()
    return [
        req
        for req in content.split("\n")
        if req != '' and not req.startswith('#')
    ]


setup(name='confluent-kafka',
      version='0.11.6',
      description='Confluent\'s Apache Kafka client for Python',
      author='Confluent Inc',
      author_email='support@confluent.io',
      url='https://github.com/confluentinc/confluent-kafka-python',
      ext_modules=[module],
      packages=find_packages(exclude=("tests", "tests.*")),
      data_files=[('', ['LICENSE.txt'])],
      install_requires=INSTALL_REQUIRES,
      extras_require={
          'avro': ['fastavro', 'requests', avro],
          'dev': get_install_requirements("test-requirements.txt")
      })
